==> central-repository-3.62.0.zip: java/lang/SecurityException.java <==
package java.lang;

/**
 * Thrown by the security manager to indicate a security violation.
 */
public class SecurityException extends RuntimeException {

	/**
	 * Constructs a <code>SecurityException</code> with no detail message.
	 */
	public SecurityException() {
		throw new RuntimeException();
	}

	/**
	 * Constructs a <code>SecurityException</code> with the specified detail message.
	 * 
	 * @param s
	 *        the detail message.
	 */
	public SecurityException(String s) {
		throw new RuntimeException();
	}

	/**
	 * Creates a <code>SecurityException</code> with the specified detail message and cause.
	 * 
	 * @param message
	 *        the detail message (which is saved for later retrieval by the {@link #getMessage()}
	 *        method).
	 * @param cause
	 *        the cause (which is saved for later retrieval by the {@link #getCause()} method). (A
	 *        <tt>null</tt> value is permitted, and indicates that the cause is nonexistent or
	 *        unknown.)
	 */
	public SecurityException(String message, Throwable cause) {
		throw new RuntimeException();
	}

	/**
	 * Creates a <code>SecurityException</code> with the specified cause and a detail message of
	 * <tt>(cause==null ? null : cause.toString())</tt> (which typically contains the class and
	 * detail message of <tt>cause</tt>).
	 * 
	 * @param cause
	 *        the cause (which is saved for later retrieval by the {@link #getCause()} method). (A
	 *        <tt>null</tt> value is permitted, and indicates that the cause is nonexistent or
	 *        unknown.)
	 */
	public SecurityException(Throwable cause) {
		throw new RuntimeException();
	}
}

==> central-repository-3.64.0.zip: java/lang/SecurityException.java <==
package java.lang;

import ej.annotation.Nullable;

/**
 * Thrown by the security manager to indicate a security violation.
 */
public class SecurityException extends RuntimeException {

	/**
	 * Constructs a <code>SecurityException</code> with no detail message.
	 */
	public SecurityException() {
		throw new RuntimeException();
	}

	/**
	 * Constructs a <code>SecurityException</code> with the specified detail message.
	 *
	 * @param s
	 *        the detail message.
	 */
	public SecurityException(String s) {
		throw new RuntimeException();
	}

	/**
	 * Creates a <code>SecurityException</code> with the specified detail message and cause.
	 *
	 * @param message
	 *        the detail message (which is saved for later retrieval by the {@link #getMessage()}
	 *        method).
	 * @param cause
	 *        the cause (which is saved for later retrieval by the {@link #getCause()} method). (A
	 *        <tt>null</tt> value is permitted, and indicates that the cause is nonexistent or unknown.)
	 */
	public SecurityException(String message, @Nullable Throwable cause) {
		throw new RuntimeException();
	}

	/**
	 * Creates a <code>SecurityException</code> with the specified cause and a detail message of
	 * <tt>(cause==null ? null : cause.toString())</tt> (which typically contains the class and detail
	 * message of <tt>cause</tt>).
	 *
	 * @param cause
	 *        the cause (which is saved for later retrieval by the {@link #getCause()} method). (A
	 *        <tt>null</tt> value is permitted, and indicates that the cause is nonexistent or unknown.)
	 */
	public SecurityException(@Nullable Throwable cause) {
		throw new RuntimeException();
	}
}
